@@ -27,6 +27,10 @@
 #'
 #' In the latter two cases (density and presence estimation) observations can be weighted by segment areas via the \code{weights=} argument. By default (\code{weights=NULL}), when density or presence are estimated the weights are set to the segment areas (using \code{segment.area} or by calculating \code{2*}(strip width)\code{*Effort}) Alternatively \code{weights=1} will set the weights to all be equal.  A third alternative is to pass in a vector of length equal to the number of segments, containing appropriate weights.
 #'
+#' @section Units:
+#'
+#' It is often the case that distances are collected in metres and segment lengths are recorded in kilometres. \code{dsm} allows you to provide a conversation factor (\code{convert.units}) to multiply the areas by. For example: if distances are in metres and segment lengths are in kilometres setting \code{convert.units=1000} will lead to the analysis being in metres. Setting \code{convert.units=1/1000} will lead to the analysis being in kilometres. The conversion factor will be applied to `segment.area` if that is specified.
+#'
 #' @section Large models:
 #'
 #' For large models, \code{engine="bam"} with \code{method="fREML"} may be useful. Models specified for \code{bam} should be as \code{gam}. READ \code{\link{bam}} before using this option; this option is considered EXPERIMENTAL at the moment. In particular note that the default basis choice (thin plate regression splines) will be slow and that in general fitting is less stable than when using \code{gam}. For negative binomial response, theta must be specified when using \code{bam}.
@@ -37,7 +41,7 @@
 #' @param segment.data segment data, see \code{\link{dsm-data}}.
 #' @param observation.data observation data, see \code{\link{dsm-data}}.
 #' @param engine which fitting engine should be used for the DSM (\code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}}/\code{\link{bam}}).
-#' @param convert.units value to alter length or width for calculation of the offset, applied to `segment.area` if used.
+#' @param convert.units conversion factor to multiply the area of the segments by. See 'Units' below.
 #' @param family response distribution (popular choices include \code{\link{quasipoisson}}, \code{\link{Tweedie}} and \code{\link{negbin}}). Defaults to \code{quasipossion}.
 #' @param group if \code{TRUE} the abundance of groups will be calculated rather than the abundance of individuals. Setting this option to \code{TRUE} is equivalent to setting the size of each group to be 1.
 #' @param control the usual \code{control} argument for a \code{gam}; \code{keepData} must be \code{TRUE} for variance estimation to work.
@@ -56,9 +60,10 @@
 #'
 #' Wood, S.N. 2006. Generalized Additive Models: An Introduction with R. CRC/Chapman & Hall.
 #' @export
+#' @importFrom stats quasipoisson
+#' @importFrom utils packageVersion
 #'
 #' @examples
-#'
 #' library(Distance)
 #' library(dsm)
 #'
@@ -66,12 +71,12 @@
 #' data(mexdolphins)
 #'
 #' # fit a detection function and look at the summary
-#' hr.model <- ds(mexdolphins$distdata, max(mexdolphins$distdata$distance), 
+#' hr.model <- ds(mexdolphins$distdata, max(mexdolphins$distdata$distance),
 #'                key = "hr", adjustment = NULL)
 #' summary(hr.model)
 #'
 #' # fit a simple smooth of x and y
-#' mod1<-dsm(N~s(x,y), hr.model, mexdolphins$segdata, mexdolphins$obsdata)
+#' mod1 <- dsm(N~s(x,y), hr.model, mexdolphins$segdata, mexdolphins$obsdata)
 #' summary(mod1)
 #'
 #' # create an offset (in metres)
@@ -90,7 +95,7 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
                 engine="gam", convert.units=1,
                 family=quasipoisson(link="log"), group=FALSE, gamma=1.4,
                 control=list(keepData=TRUE), availability=1, strip.width=NULL,
-                segment.area=NULL,weights=NULL,...){
+                segment.area=NULL, weights=NULL, ...){
 
   # if we have a model fitted using Distance, then just pull out the
   # ddf component
@@ -102,9 +107,9 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
 
   ## check the formula
   response <- as.character(formula)[2]
-  possible.responses <- c("D","density","Dhat","density.est",
-                          "N","abundance","count","n",
-                          "Nhat","abundance.est",
+  possible.responses <- c("D", "density", "Dhat", "density.est",
+                          "N", "abundance", "count", "n",
+                          "Nhat", "abundance.est",
                           "presence")
   if(!(response %in% possible.responses)){
     stop(paste("Model must be one of:",
@@ -125,13 +130,13 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
   ##  to the formula
   if(!(response %in% c("D","density","Dhat","density.est","presence"))){
     formula <- as.formula(paste(c(as.character(formula)[c(2,1,3)],
-                                "+ offset(off.set)"),collapse=""))
+                                "+ offset(off.set)"), collapse=""))
   }else{
     # set the weights if we are doing density or presence estimation
     if(is.null(weights)){
       weights <- dat$segment.area
     }else if(length(weights)==1){
-      weights <- rep(1,nrow(dat))
+      weights <- rep(1, nrow(dat))
     }
   }
 
@@ -157,9 +162,9 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
                  data    = dat,
                  gamma   = gamma,
                  weights = weights,
-                 control = control,...)
+                 control = control, ...)
 
-    fit <- withCallingHandlers(do.call(engine,args),
+    fit <- withCallingHandlers(do.call(engine, args),
                                warning=matrixnotposdef.handler)
   }else{
     stop("engine must be one of 'gam', 'gamm', 'bam' or 'glm'")
@@ -178,12 +183,11 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
     fit$gam$gamma <- gamma
     # yucky way to get dsm.var/dsm.var.prop to work because gamm()
     #  doesn't store the call()
-    fit$gam$gamm.call.list <- substitute(list(...))
-    fit$gam$gamm.call.list$formula <- formula
-    fit$gam$gamm.call.list$family <- family
-    fit$gam$gamm.call.list$data <- dat
-    fit$gam$gamm.call.list$gamma <- gamma
-    fit$gam$gamm.call.list$control <- control
+    fit$gam$gamm.call.list <- list(formula = formula,
+                                   family  = family,
+                                   data    = dat,
+                                   gamma   = gamma,
+                                   control = control)
   }else{
     fit$ddf <- ddf.obj
     fit$gamma <- gamma
