@@ -2,8 +2,6 @@
 #'
 #' Gives a brief summary of a fitted \code{dsm} variance object. 
 #'
-#' @S3method summary dsm.var
-#' @method summary dsm.var
 #' @aliases summary.dsm.var
 #'
 #' @param object a \code{dsm.var} object
@@ -16,11 +14,12 @@
 #'        with variance propagation).
 #' @param \dots unused arguments for S3 compatibility
 #' @return a summary object
+#' @export
 #'
 #' @seealso dsm.var.movblk dsm.var.prop
 #' @author David L. Miller
 #'
-summary.dsm.var<-function(object, alpha=0.05, boxplot.coef=1.5, 
+summary.dsm.var<-function(object, alpha=0.05, boxplot.coef=1.5,
                   bootstrap.subregions=NULL,...){
 
   # storage
@@ -42,11 +41,28 @@ summary.dsm.var<-function(object, alpha=0.05, boxplot.coef=1.5,
     # bootstrap abundances
     bootstrap.abund <- object$study.area.total
 
-    # delta method, if necessary
-    if(!object$ds.uncertainty){
+    # when we don't need to do the delta method
+    if(is.null(object$dsm.object$ddf) | object$ds.uncertainty){
 
-      ddf.object<-object$dsm.object$ddf
-      ddf.summary<-summary(ddf.object)
+      # if we used detection function uncertainty
+      # or there was no detection function
+
+      # variance of the bootstrap abundances is the variance
+      trimmed.variance <- trim.var(bootstrap.abund[is.finite(bootstrap.abund)],
+                                   boxplot.coef=boxplot.coef)
+
+      sinfo$var <- trimmed.variance
+      sinfo$se <- sqrt(trimmed.variance)
+
+      sinfo$cv <- sinfo$se/sinfo$pred.est
+      # in this case bootstrap and regular CV are the same
+      sinfo$bootstrap.cv <- sinfo$cv
+    }else{
+      # delta method, if necessary
+      #  - if we didn't incorporate detection function uncertainty in bootstrap
+      #  - if there was a detection function
+
+      ddf.summary <- summary(object$dsm.object$ddf)
 
       # average p standard error
       sinfo$average.p.se <- ddf.summary$average.p.se
@@ -75,17 +91,6 @@ summary.dsm.var<-function(object, alpha=0.05, boxplot.coef=1.5,
       # variance (delta method)
       sinfo$var <- (cvN*sinfo$pred.est)^2
       sinfo$se <- sqrt(sinfo$var)
-    }else{
-      # if we used detection function uncertainty
-
-      # variance of the bootstrap abundances is the variance
-      trimmed.variance <- trim.var(bootstrap.abund[is.finite(bootstrap.abund)],
-                                   boxplot.coef=boxplot.coef)
-
-      sinfo$var <- trimmed.variance
-      sinfo$se <- sqrt(trimmed.variance)
-
-      sinfo$cv <- sinfo$se/sinfo$pred.est
     }
 
     ### general bootstrap stuff
@@ -131,7 +136,7 @@ summary.dsm.var<-function(object, alpha=0.05, boxplot.coef=1.5,
       sinfo$subregions<-subregions
     }
 
-  }else if(object$bootstrap==FALSE){
+  }else{
   ### varprop and "Bayesian" stuff
     sinfo$varprop <- !is.null(object$deriv)
     sinfo$saved<-object
@@ -162,13 +167,16 @@ summary.dsm.var<-function(object, alpha=0.05, boxplot.coef=1.5,
       sinfo$se <- sqrt(var.prop$pred.var)
     }
     # grab the predicted values
-    if(length(object$pred)>1 | length(object$pred)==0){
-      dsm.obj <- object$dsm.obj
-      class(dsm.obj) <- c("dsm",class(dsm.obj))
-      mod1.pred <- predict(dsm.obj,
-                           newdata=object$pred.data,
-                           off.set=object$off.set)
-      sinfo$pred.est <- sum(mod1.pred,na.rm=TRUE)
+#    if(length(object$pred)==0){
+#      dsm.obj <- object$dsm.obj
+#      class(dsm.obj) <- c("dsm",class(dsm.obj))
+#      mod1.pred <- predict(dsm.obj,
+#                           newdata=object$pred.data,
+#                           off.set=object$off.set)
+#      sinfo$pred.est <- sum(mod1.pred,na.rm=TRUE)
+#    }else if(length(object$pred)>1 | length(object$pred)==0){
+    if(length(object$pred)>1){
+      sinfo$pred.est <- sum(unlist(object$pred), na.rm=TRUE)
     }else{
       sinfo$pred.est <- object$pred[[1]]
     }
@@ -181,8 +189,8 @@ summary.dsm.var<-function(object, alpha=0.05, boxplot.coef=1.5,
     }else{
     # if we're just using the GAM variance, then we need to combine using
     # the delta method
-      ddf.object<-object$dsm.object$ddf
-      ddf.summary<-summary(ddf.object)
+      ddf.summary<-summary(object$dsm.object$ddf)
+
       cvp.sq <- (ddf.summary$average.p.se/
                  ddf.summary$average.p)^2
       sinfo$detfct.cv <- sqrt(cvp.sq)
